@@ -13,22 +13,9 @@ os.environ["SKIP_ADAPTER"] = "False"
 
 header = {"Content-Type": "application/json"}
 
-env = os.environ.get("ENV", "beta")
-
 
 def get_probe_runner_host():
-    if env.lower() == 'stage':
-        return "https://proberunner.internal.mum1-stage.zetaapps.in"
-    if env.lower() == 'pre-prod':
-        return "https://proberunner.internal.mum1-pp.zetaapps.in"
-    if env.lower() == 'beta':
-        return "https://proberunner.internal.hdfc-beta.zetaapps.in"
-    if env.lower() == 'lz':
-        return "https://proberunner.hdfclz.zetaapps.in"
-    if env.lower() == 'ow':
-        return "https://proberunner.internal.olympus-world.zetaapps.in"
-    else:
-        raise ValueError("Incorrect argument passed as env : " + env)
+    return "https://proberunner.internal.olympus-world.zetaapps.in"
 
 
 def trace():
@@ -66,9 +53,9 @@ def logged_request(method, url, **kwargs):
         start_time = int(time.time() * 1000)
 
         try:
-            header_dict: dict = kwargs.get('headers', None)
-            if header_dict is not None:
-                header_dict.update(trace())
+            # header_dict: dict = kwargs.get('headers', None)
+            # if header_dict is not None:
+            #     header_dict.update(trace())
             response = original_request_method(method, url, **kwargs)
             request = response.request
         finally:
@@ -96,9 +83,11 @@ def adapter_data(*, start_time, end_time, request=None, response=None, method=No
     if request is not None:
         trace_id = request.headers.get("X-Olympus-Traceid", None)
         flow_id = os.environ.get("FLOW_ID", None)
+        zone = os.environ.get("ZONE", None)
 
-        if trace_id is not None and flow_id is not None:
+        if flow_id is not None and zone is not None:
             del os.environ["FLOW_ID"]
+            del os.environ["ZONE"]
 
             if response.status_code >= 500:
                 flag = 3
@@ -123,6 +112,7 @@ def adapter_data(*, start_time, end_time, request=None, response=None, method=No
                 "flowId": flow_id,
                 "probeType": "FLOW",
                 "probeRunnerType": "JENKINS",
+                "zone": zone,
                 "crd": "test CRDx"
             }
 
@@ -138,7 +128,7 @@ def adapter_data(*, start_time, end_time, request=None, response=None, method=No
                 "status": flag
             }]
 
-            probe_id = get_probe(flow_probe_name, flow_id)
+            probe_id = get_probe(flow_probe_name, flow_id, zone)
 
             if probe_id != "":
                 save_probe_invocation(probe_id, probe_data)
@@ -155,7 +145,8 @@ def adapter_data(*, start_time, end_time, request=None, response=None, method=No
                     "probeName": flow_probe_name_with_id,
                     "probeId": probe_id,
                     "flowId": flow_id,
-                    "flowName": flow_id
+                    "flowName": flow_id,
+                    "zone": zone
                 },
                 "metricValue": flag
             }
@@ -163,12 +154,13 @@ def adapter_data(*, start_time, end_time, request=None, response=None, method=No
             push_to_prometheus(prometheus_push_body)
 
 
-def get_probe(flow_probe_name, flow_id):
+def get_probe(flow_probe_name, flow_id, zone):
     os.environ["SKIP_ADAPTER"] = "True"
-    get_probe_url = get_probe_runner_host() + f"/probe/{flow_probe_name}/flow/{flow_id}"
+    get_probe_url = get_probe_runner_host() + f"/probe/{flow_probe_name}/flow/{flow_id}?zone={zone}"
     response = requests.get(get_probe_url, headers=header)
     os.environ["SKIP_ADAPTER"] = "False"
     if response.text:
+        print(f"Get probe response : {response.json()}")
         return response.json()["probeId"]
     else:
         return ""
@@ -183,6 +175,7 @@ def save_probe_invocation(probe_id, probe_data):
         return response.text
     os.environ["SKIP_ADAPTER"] = "False"
     if response.text == "1 invocations saved":
+        print(f"Save probe invocation : {response.text}")
         return True
     else:
         if response.json()["message"] == "failure to get a peer from the ring-balancer":
@@ -196,6 +189,7 @@ def create_probe(create_probe_body):
     response = requests.post(create_probe_url, data=data, headers=header)
     os.environ["SKIP_ADAPTER"] = "False"
     if response.status_code == 200:
+        print(f"Create probe response : {response.json()}")
         return response.json()["probeId"]
     else:
         raise TypeError("Could not create a probe.")
@@ -204,10 +198,10 @@ def create_probe(create_probe_body):
 def push_to_prometheus(prometheus_push_body):
     os.environ["SKIP_ADAPTER"] = "True"
     push_to_prometheus_url = get_probe_runner_host() + "/prometheus/push?jobName=PROBE-METRICS"
-    data = json.dumps(prometheus_push_body)
-    response = requests.post(push_to_prometheus_url, data=data, headers=header)
+    response = requests.post(push_to_prometheus_url, json=prometheus_push_body, headers=header)
     os.environ["SKIP_ADAPTER"] = "False"
     if response.status_code == 200:
+        print(f"Push to prometheus : {response.text}")
         return
     else:
         raise TypeError("Could not push data to prometheus.")
